# -*- coding: utf-8 -*-
# Generated by Django 1.11.20 on 2019-09-23 15:14
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('turkle', '0002_add_batch_level_permissions'),
    ]

    operations = [
        migrations.AddField(
            model_name='batch',
            name='custom_permissions',
            field=models.BooleanField(default=False),
        ),
    ]
