{% extends "turkle/base.html" %}
{% load i18n static %}

{% block body %}

<div class="container mt-5">

  {% block content %}
  <div class="card w-50">
    <div class="card-body">

      {% block content_title %}<h1>{{ title }}</h1>{% endblock %}

      <p>{% trans "Forgotten your password? Enter your email address below, and we'll email instructions for setting a new one." %}</p>

      <form method="post">{% csrf_token %}
        <table>
          <tr>
            <td>{{ form.email.errors }}</td>
            <td>
              <label for="id_email">{% trans 'Email address:' %}</label>
            </td>
            <td>
              {{ form.email }}
            </td>
          </tr>
        </table>
        <input type="submit" value="{% trans 'Reset my password' %}" class="btn btn-primary" />
      </form>
    </div>
  </div>
  {% endblock %}

</div>

{% endblock %}
