# -*- coding: utf-8 -*-
# Generated by Django 1.11.20 on 2019-09-17 15:37
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('turkle', '0001_initial'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='batch',
            options={'permissions': (('can_work_on_batch', 'Can work on Tasks for this Batch'),), 'verbose_name': 'Batch', 'verbose_name_plural': 'Batches'},
        ),
    ]
