{% extends "admin/base.html" %}
{% load static %}

{% block title %}{{ title }} | {{ site_title|default:_('Django site admin') }}{% endblock %}

{% block branding %}
<h1 id="site-name"><a href="{% url 'admin:index' %}">{{ site_header|default:_('Django administration') }}</a></h1>
{% endblock %}

{% block nav-global %}{% endblock %}

{% block extrastyle %}{{ block.super }}<link rel="stylesheet" type="text/css" href="{% static "admin/css/turkle-admin-theme.css" %}" />{% endblock %}

{% block extrahead %}
  {{ block.super }}
  <link rel="icon" type="image/png" sizes="32x32" href="{% static 'favicon-32x32.png' %}">
  <link rel="icon" type="image/png" sizes="16x16" href="{% static 'favicon-16x16.png' %}">
{% endblock %}

{% block footer %}<div id="footer">Turkle version {{turkle_version}}</div>{% endblock %}