{% extends "admin/base_site.html" %}

{# This is only shown when logging out of admin #}

{% block breadcrumbs %}<div class="breadcrumbs"><a href="{% url 'admin:index' %}">Home</a></div>{% endblock %}

{% block content %}

<p>You are logged out of {{turkle_site_name}} administration.</p>

<p><a href="{% url 'admin:index' %}">Log in again</a></p>

{% endblock %}