{% extends "turkle/base.html" %}
{% load i18n static %}

{% block body %}

<div class="container mt-5">

  {% block content %}
  <div class="card w-50">
    <div class="card-body">
      {% block content_title %}<h1>{{ title }}</h1>{% endblock %}

      <p>{% trans "We've emailed instructions for resetting your password if an account exists with the email you entered. You should receive them shortly." %}</p>

      <p>{% trans "If you don't receive an email, please make sure you've entered the address you registered with and check your spam folder." %}</p>
    </div>
  </div>
  {% endblock %}

</div>

{% endblock %}
