# Generated by Django 2.2.19 on 2021-04-07 15:35

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('turkle', '0009_batch_completed'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='project',
            options={'ordering': ['-id'], 'permissions': (('can_work_on', 'Can work on Tasks for this Project'),), 'verbose_name': 'Project'},
        ),
        migrations.AddField(
            model_name='project',
            name='allotted_assignment_time',
            field=models.IntegerField(default=24),
        ),
    ]
