# -*- coding: utf-8 -*-
# Generated by Django 1.11.20 on 2019-09-23 15:30
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('turkle', '0003_batch_custom_permissions'),
    ]

    operations = [
        migrations.AddField(
            model_name='batch',
            name='login_required',
            field=models.BooleanField(db_index=True, default=True),
        ),
    ]
