{% extends "turkle/base.html" %}
{% load i18n static %}

{% block body %}

<div class="container mt-5">

  {% block content %}
  <div class="card w-50">
    <div class="card-body">
      {% block content_title %}
      <h1>{{ title }}</h1>{% endblock %}
      <p>{% trans "Your password has been reset.  You can log in now." %}</p>
      <p><a href="{% url 'login' %}">{% trans 'Log in' %}</a></p>
    </div>
  </div>
  {% endblock %}

</div>

{% endblock %}
