/* Admin css for the turkle app included through Media class */

/* Django admin css removed these classes in 3.0 */
.float-right {
    float: right;
}
.float-left {
    float: left;
}
.align-center {
    text-align: center;
}
.align-right {
    text-align: right;
}
.align-left {
    text-align: left;
}

/* Based on bootstrap inline form CSS */
.inline-form-buttons > form,
.inline-form-buttons > a[role="button"]
{
  display: inline-block;
  margin-left: 1em;
}

.turkle-file-error {
  clear: left;
}

.ml-2 {
  margin-left: 2em;
}
.mr-2 {
  margin-right: 2em;
}
.mt-2 {
  margin-top: 2em;
}
.mb-2 {
  margin-bottom: 2em;
}

iframe {
  top: 0;
  bottom: 0;
  left: 0;
  width: 100%;
  height: 100%;
  border: 0;
  box-sizing: inherit;
  display: block;
}

/* Style rules copied from:  http://parsleyjs.org/src/parsley.css */
input.parsley-success,
select.parsley-success,
textarea.parsley-success {
  color: #468847;
  background-color: #DFF0D8;
  border: 1px solid #D6E9C6;
}
input.parsley-error,
select.parsley-error,
textarea.parsley-error {
  color: #B94A48;
  background-color: #F2DEDE;
  border: 1px solid #EED3D7;
}
.parsley-errors-list {
  margin: 2px 0 3px;
  padding: 0;
  list-style-type: none;
  font-size: 0.9em;
  line-height: 0.9em;
  opacity: 0;
  color: #B94A48;

  transition: all .3s ease-in;
  -o-transition: all .3s ease-in;
  -moz-transition: all .3s ease-in;
  -webkit-transition: all .3s ease-in;
}
.parsley-errors-list.filled {
  opacity: 1;
}
